@@ -10,14 +10,14 @@
 
 
 int main(int argc, char* argv[]) {
-	struct stat *info;
+	struct stat info;
 
-	if (stat(PROCFILE, info) != 0) {
+	if (stat(PROCFILE, &info) != 0) {
 		perror ("Could not stat " PROCFILE);
 		exit(EXIT_FAILURE);
 	}
 	
-	if (chmod(PROCFILE, (info->st_mode & 000777) | S_IWOTH) != 0) {
+	if (chmod(PROCFILE, (info.st_mode & 000777) | S_IWOTH) != 0) {
 		perror ("Could not change permissions of " PROCFILE);
 		exit(EXIT_FAILURE);
 	}
